<?php
// listado.php
// Incluimos el archivo de conexión a la base de datos
include 'db.php';

// Preparamos la consulta SQL para obtener todos los registros de la tabla 'items'
$sql = "SELECT * FROM items";

// Ejecutamos la consulta y almacenamos el resultado
$result = $conn->query($sql);

// Verificamos si se obtuvieron registros
if ($result->num_rows > 0) {
    // Creamos un array para almacenar los registros
    $items = [];
    while ($row = $result->fetch_assoc()) {
        $items[] = $row;
    }
} else {
    $message = "No se encontraron registros";
}

// Cerramos la conexión a la base de datos
$conn->close();
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Listado de Registros</title>
    <style>
        /* Estilos para la página */
        body {
            font-family: Arial, sans-serif; /* Fuente para el texto */
            margin: 20px; /* Margen alrededor de la página */
            background-color: #f4f4f4; /* Color de fondo de la página */
        }
        .container {
            max-width: 800px; /* Ancho máximo del contenedor */
            margin: auto; /* Centra el contenedor horizontalmente */
            padding: 20px; /* Relleno dentro del contenedor */
            background: #fff; /* Color de fondo del contenedor */
            border-radius: 8px; /* Bordes redondeados del contenedor */
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1); /* Sombra alrededor del contenedor */
        }
        h1 {
            color: #333; /* Color del texto del encabezado */
        }
        table {
            width: 100%; /* Ancho de la tabla ocupa todo el contenedor */
            border-collapse: collapse; /* Colapsa los bordes de la tabla */
        }
        th, td {
            border: 1px solid #ddd; /* Borde de las celdas de la tabla */
            padding: 10px; /* Relleno dentro de las celdas */
            text-align: left; /* Alineación del texto a la izquierda */
        }
        th {
            background-color: #f2f2f2; /* Color de fondo de los encabezados de columna */
        }
        .action-links {
            text-align: center; /* Centra el texto de los enlaces de acción */
        }
        .action-links a {
            margin: 0 5px; /* Espaciado entre los enlaces */
            text-decoration: none; /* Sin subrayado en los enlaces */
            color: #007BFF; /* Color del texto de los enlaces */
        }
        .action-links a:hover {
            text-decoration: underline; /* Subrayado al pasar el ratón sobre el enlace */
        }
        .back-link {
            display: block; /* Hace que el enlace sea un bloque para centrarlo */
            text-align: center; /* Centra el texto del enlace */
            margin-top: 20px; /* Margen superior para el enlace */
            font-size: 16px; /* Tamaño de fuente del enlace */
        }
    </style>
</head>
<body>
    <div class="container">
        <h1>Listado de Registros</h1>
        <!-- Muestra el mensaje si existe -->
        <?php if (isset($message)): ?>
            <p class="message"><?php echo $message; ?></p>
        <?php endif; ?>
        <!-- Tabla para mostrar los registros -->
        <table>
            <thead>
                <tr>
                    <th>ID</th>
                    <th>Nombre</th>
                    <th>Descripción</th>
                    <th>Acciones</th>
                </tr>
            </thead>
            <tbody>
                <!-- Recorremos el array de registros y mostramos cada uno en una fila de la tabla -->
                <?php if (isset($items)): ?>
                    <?php foreach ($items as $item): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($item['id']); ?></td>
                            <td><?php echo htmlspecialchars($item['nombre']); ?></td>
                            <td><?php echo htmlspecialchars($item['descripcion']); ?></td>
                            <td class="action-links">
                                <!-- Enlaces para modificar y eliminar el registro -->
                                <a href="modificar.php?id=<?php echo $item['id']; ?>">Modificar</a>
                                <a href="baja.php?id=<?php echo $item['id']; ?>">Eliminar</a>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                <?php endif; ?>
            </tbody>
        </table>
        <a href="alta.php" class="back-link">Agregar Nuevo Registro</a>
    </div>
</body>
</html>